@@ -84,7 +84,7 @@ class Client_v1(AbstractContextManager):
         response.raise_for_status()
         return response.content
 
-    def get(self, url):
+    def get(self, url_path, **url_params):
         """
         This function delegates to get_xml() and parses the
         response xml to return a dict
@@ -94,13 +94,21 @@ class Client_v1(AbstractContextManager):
 
         Usage:
           dict = netdot.Client.get("/url")
+          dict = netdot.Client.get("/url", depth=2)
 
         Returns:
           Result as a multi-level dictionary on success.
         """
-        return parse.RESTful_XML(self.get_xml(url))
+        final_url = url_path
+        if url_params:
+            url_params_list = list()
+            for field, value in url_params.items():
+                url_params_list.append(f'{field}={value}')
+            url_params_str = '&'.join(url_params_list)
+            final_url = f'{url_path}?{url_params_str}'
+        return parse.RESTful_XML(self.get_xml(final_url))
 
-    def get_object_by_filter(self, object, field, value):
+    def get_object_by_filter(self, object, field, value, **url_params):
         """
         Returns a multi-level dict of an objects (device, interface, rr, person)
         filtered by an object field/attribute
@@ -115,8 +123,8 @@ class Client_v1(AbstractContextManager):
         Returns:
           Multi-level dictionary on success
         """
-        url = "/{}?{}={}".format(object, field, value)
-        return self.get(url)
+        url_params[field] = value
+        return self.get(f'/{object}', **url_params)
 
     def post(self, url, data):
         """
@@ -245,7 +253,7 @@ class Client(Client_v1):
             logger.warning(f'Unable to decode {ENCODING} data: {response}')
             return response
 
-    def get(self, url_path: str) -> Dict:
+    def get(self, url_path: str, **url_params) -> Dict:
         """Get some data from Netdot REST API.
 
         Arguments:
@@ -254,27 +262,27 @@ class Client(Client_v1):
         Returns:
             Dict: Result as a multi-level dictionary on success.
         """
-        return self._get_with_retries(url_path, times_to_retry=self._retries)
+        return self._get_with_retries(url_path, times_to_retry=self._retries, **url_params)
 
-    def _get_with_retries(self, url_path: str, times_to_retry: int):
+    def _get_with_retries(self, url_path: str, times_to_retry: int, **url_params):
         """Wrapper around super().get. Retry the get request if it fails.
         """
         try:
-            return self._get_convert_404_to_empty(url_path)
+            return self._get_convert_404_to_empty(url_path, **url_params)
         except requests.exceptions.RequestException as e:
             if times_to_retry > 0:
                 logger.warning(
                     f"Request failed due to {type(e)}. Will retry {times_to_retry} more times. (endpoint: {url_path}).")
                 logger.debug(str(e))
-                return self._get_with_retries(url_path, times_to_retry - 1)
+                return self._get_with_retries(url_path, times_to_retry - 1, **url_params)
             else:
                 raise e
 
-    def _get_convert_404_to_empty(self, url_path: str):
+    def _get_convert_404_to_empty(self, url_path: str, **url_params):
         """Wrapper around super().get. Ensures that 'empty' is returned instead of 404.
         """
         try:
-            return super().get(url_path)
+            return super().get(url_path, **url_params)
         except requests.exceptions.HTTPError as http_error:  # 404 response means 'no entries found'
             if http_error.response.status_code == 404:
                 logger.debug(
@@ -285,11 +293,11 @@ class Client(Client_v1):
             else:
                 raise http_error
 
-    def get_object_by_filter(self, table: str, column: str, search_term: Any) -> List[Dict]:
+    def get_object_by_filter(self, table: str, column: str, search_term: Any, **url_params) -> List[Dict]:
         """Filter records from a table. Retrieve all the records from the "table" that match the 
         provided "search_term", for "column".
 
-        NOTE: HTTP 404 erros are logged and 'empty dict' is returned.
+        NOTE: HTTP 404 errors are logged and 'empty dict' is returned.
 
         Args:
             table (str): The table name of the table to be searched (in CamelCase).
@@ -302,7 +310,7 @@ class Client(Client_v1):
         Returns:
             List: A list of any objects that match "search_term" for "column" in "table".
         """
-        data = super().get_object_by_filter(table, column, search_term)
+        data = super().get_object_by_filter(table, column, search_term, **url_params)
         if len(data) > 1:
             logger.warning(textwrap.dedent(
                 f'''Netdot API returned more data items than expected when attempting to 
@@ -313,7 +321,7 @@ class Client(Client_v1):
             return list(data.values())
         return list()
 
-    def get_object_by_id(self, table: str, id: int) -> Dict:
+    def get_object_by_id(self, table: str, id: int, **url_params) -> Dict:
         """Retrieve the object from 'table' with the given 'id'.
 
         NOTE: HTTP 404 erros are logged and 'empty dict' is returned.
@@ -327,7 +335,7 @@ class Client(Client_v1):
 
         returns
         """
-        objects = self.get_object_by_filter(table, 'id', id)
+        objects = self.get_object_by_filter(table, 'id', id, **url_params)
 
         if len(objects) > 1:
             logger.error(f'Found multiple {table} with id={id}: {objects}')
@@ -337,8 +345,8 @@ class Client(Client_v1):
         else:
             raise ValueError(f'Unable to find {table} with id: {id}')
 
-    def get_all(self, table: str) -> List:
-        all_data = self.get(f'/{table}')
+    def get_all(self, table: str, **url_params) -> List:
+        all_data = self.get(f'/{table}', **url_params)
         all_data = all_data[table]
         all_objects = list(all_data.values())
         return all_objects
