@@ -8,6 +8,7 @@ from .site import Site
 from .vlan import VLAN
 from .physaddr import PhysAddr
 from .fwtable import FWTable, FWTableEntry
+from .dns import ResourceRecordCNAME, ResourceRecord, ResourceRecordAddress
 
 _initialized = False
 
@@ -26,6 +27,9 @@ def initialize():
         Site()
         VLAN()
         PhysAddr()
+        ResourceRecordCNAME()
+        ResourceRecord()
+        ResourceRecordAddress()
         _initialized = True
 
 
@@ -35,5 +39,5 @@ IPContainer = IPBlock
 
 __all__ = [
     'initialize', 'Asset', 'Device', 'Interface', 'IPBlock', 'Subnet', 'IPAddr', 'IPContainer',
-    'Product', 'ProductType', 'Site', 'VLAN', 'NetdotAPIDataclass', 'PhysAddr', 'FWTable', 'FWTableEntry',
+    'Product', 'ProductType', 'Site', 'VLAN', 'NetdotAPIDataclass', 'PhysAddr', 'FWTable', 'FWTableEntry',         'ResourceRecordCNAME', 'ResourceRecord', 'ResourceRecordAddress'
 ]
