@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 
-from netdot import parse
+from netdot import validate
 from netdot.csv_util import CSVDataclass
 from netdot.dataclasses.base import NetdotAPIDataclass
 
