@@ -2,13 +2,14 @@ from __future__ import absolute_import
 
 import logging
 import textwrap
-from collections import defaultdict
+from concurrent.futures import ThreadPoolExecutor
 from getpass import getpass
 from typing import Callable, List, TypeVar
 
 import uologging
 
 import netdot.dataclasses
+from netdot.dataclasses.base import NetdotAPIDataclass
 
 from . import client, utils, validate
 
@@ -27,12 +28,16 @@ class Repository:
     _initialized = False
     _existing_connection = None
 
-    def __init__(self, netdot_url, user, password, **kwargs):
+    def __init__(self, netdot_url, user, password, threads=10,**kwargs):
         Repository.prepare_class()
         self._netdot_url = netdot_url
         self._user = user
         self._connection = client.Client(netdot_url, user, password, **kwargs)
         self._products_indexed_by_name = None
+        self._thread_count = threads
+
+    def _create_thread_pool(self):
+        return ThreadPoolExecutor(self._thread_count)
 
     def __str__(self):
         return f"Repository('{self._netdot_url}', '{self._user}')"
@@ -52,7 +57,7 @@ class Repository:
             cls._initialized = True
 
     @classmethod
-    def connect(cls, _input=input, _getpass=getpass):
+    def connect(cls, _input=input, _getpass=getpass, *args, **kwargs):
         """Connect to NetDot within a python REPL session.
 
         Example:
@@ -89,7 +94,7 @@ class Repository:
         return connection
 
     @classmethod
-    def _connect(cls, _input=input, _getpass=getpass):
+    def _connect(cls, _input=input, _getpass=getpass, *args, **kwargs):
         default_netdot_url = 'https://nsdb.uoregon.edu'
         netdot_url = (
             _input(
@@ -98,7 +103,7 @@ class Repository:
         )
         user = input('NetDot username: ')
         password = _getpass('NetDot password: ')
-        return cls(netdot_url, user, password)
+        return cls(netdot_url, user, password, *args, **kwargs)
 
     @property
     def connection(self) -> 'client.Client':
@@ -117,15 +122,29 @@ class Repository:
         ]
 
     def _get_entity_by_address(self, address: str, cls, **url_params):
-        data = self.connection.get_object_by_filter(
-            cls.NETDOT_TABLE_NAME, 'address', address)
+        return self._get_unique_by_filter(cls, 'address', address, **url_params)
+
+    def _get_unique_by_filter(self, cls: NetdotAPIDataclass, search_field: str, search_term: str, **url_params) -> NetdotAPIDataclass:
+        """Try to retrieve a SINGLE object from netdot.
+
+        Logs a WARNING to the console if multiple objects from netdot match this search.
+
+        Args:
+            cls (NetdotAPIDataclass): The type of object to retrieve.
+            search_field (str): Which field of 'cls' should we be filtering by?
+            search_term (str): The unique search term.
+
+        Returns:
+            NetdotAPIDataclass: The parsed object that matches the provided search_field and search_term.
+        """
+        data = self.connection.get_object_by_filter(cls.NETDOT_TABLE_NAME, search_field, search_term, **url_params)
         matching_entities = [
             cls.from_DTO(entity_data).with_repository(self)
             for entity_data in data
         ]
         if len(matching_entities) > 1:
             logger.warning(
-                f'Found more than one matching address for {address} ({cls.__name__}): {matching_entities}')
+                f'Found more than one matching address for {search_term} ({cls.__name__}): {matching_entities}')
         elif len(matching_entities) < 1:
             return None
         return matching_entities[0]
@@ -155,20 +174,22 @@ class Repository:
         most_recent_scan_time = max(timestamps)
         most_recent_entries = list(filter(lambda entry: entry.timestamp == most_recent_scan_time, entries))
 
-        interface_counts = defaultdict(int)
         # TODO can we omit the calls to get_fwtableentries_by_interface? Perhaps the "entries" already loaded is sufficient to lookup interface_counts.
-        for entry in most_recent_entries:
+        def get_related_fwtableentries(entry: netdot.dataclasses.FWTableEntry):
             interface = entry.get_interface()
-            fwtableentries_for_interface = self.get_fwtableentries_by_interface(interface, fwtable=entry.fwtable_xlink)
-            interface_counts[entry.interface] = len(fwtableentries_for_interface)
+            return self.get_fwtableentries_by_interface(interface, fwtable=entry.fwtable_xlink)
 
-        interface_counts = dict(sorted(interface_counts.items(), key=lambda item: item[1]))
-        most_recent_interface = list(interface_counts.keys())[0]
-        most_recent_entity_list = list(filter(lambda entry: entry.interface == most_recent_interface, most_recent_entries))
-        if (len(most_recent_entity_list) != 1):
-            logger.warning(f'Expected to find one entity. Instead found: {most_recent_entity_list}')
-        most_recent_entity = most_recent_entity_list[0]
-        return most_recent_entity.get_interface()
+        with self._create_thread_pool() as executor:
+            related_fwtableentries = executor.map(get_related_fwtableentries, most_recent_entries)
+            least_fwtableentries = min(related_fwtableentries, key=len)
+            most_recent_entry = max(least_fwtableentries, key=id)
+            return most_recent_entry.get_interface()
+
+    def get_rr_by_address(self, address: str) -> 'netdot.dataclasses.ResourceRecord':
+        ipblock = self.get_ipblock_by_address(address)
+        rraddr = self._get_unique_by_filter(netdot.dataclasses.ResourceRecordAddress, 'ipblock', ipblock.id)
+        # resource_record_link = self._get_entity_by_address(ipblock.id, netdot.dataclasses.ResourceRecordAddress, address_xlink_name='ipblock')
+        return self.get_rr(rraddr.rr_xlink)
 
     def get_ipblock_by_address(self, address: str) -> 'netdot.dataclasses.IPBlock':
         """Get some IP Block from Netdot Address Space.
