@@ -3,8 +3,11 @@
 Note: Raise an Error validation fails.
 """
 
+import logging
+
 from netdot.exceptions import NetdotError
 
+logger = logging.getLogger(__name__)
 
 def VLAN_id(vlan_id: int):
     # ensure: 1 <= vid <= 4094
@@ -16,4 +19,5 @@ def RESTful_XML(content):
     expected_root_token = '<opt'
     xml_message = str(content)
     if expected_root_token not in xml_message:
+        logger.error(f'Expected {expected_root_token} to be root of XML response. Response: {xml_message}')
         raise NetdotError(f'Expected {expected_root_token} to be root of XML response. Response: {xml_message[:256]}... trimmed for brevity...')
