@@ -16,7 +16,7 @@ def ignore_redirected_html_after_login(response):
     """
     try:
         if response['body']['string'].strip().startswith(b'<html>'):
-            response['body']['string'] = 'BLANK (see conftest.py)'
+            response['body']['string'] = 'HTML content ignored (see conftest.py)'
     except TypeError:
         pass
     return response
